@@ -53,9 +53,11 @@ use liquid::ValueView;
 use project_variables::{StringEntry, TemplateSlots, VarInfo};
 use std::{
     borrow::Borrow,
+    cell::RefCell,
     collections::HashMap,
     env, fs,
     path::{Path, PathBuf},
+    rc::Rc,
 };
 
 use tempfile::TempDir;
@@ -79,7 +81,7 @@ pub fn generate(mut args: Args) -> Result<()> {
     let (template_base_dir, template_folder, branch) = prepare_local_template(&args)?;
 
     let template_config = Config::from_path(
-        &locate_template_file(CONFIG_FILE_NAME, &template_base_dir, &args.subfolder).ok(),
+        &locate_template_file(CONFIG_FILE_NAME, &template_base_dir, &template_folder).ok(),
     )?
     .unwrap_or_default();
 
@@ -346,24 +348,23 @@ pub(crate) fn copy_dir_all(src: impl AsRef<Path>, dst: impl AsRef<Path>) -> Resu
     copy_all(src, dst)
 }
 
-fn locate_template_file<T>(
+fn locate_template_file<T1, T2>(
     name: &str,
-    template_folder: T,
-    subfolder: &Option<String>,
+    template_base_folder: T1,
+    template_folder: T2,
 ) -> Result<PathBuf>
 where
-    T: AsRef<Path>,
+    T1: AsRef<Path>,
+    T2: AsRef<Path>,
 {
-    let template_folder = template_folder.as_ref().to_path_buf();
-    let mut search_folder = subfolder
-        .as_ref()
-        .map_or_else(|| template_folder.to_owned(), |s| template_folder.join(s));
+    let template_base_folder = template_base_folder.as_ref();
+    let mut search_folder = template_folder.as_ref().to_path_buf();
     loop {
         let file_path = search_folder.join(name.borrow());
         if file_path.exists() {
             return Ok(file_path);
         }
-        if search_folder == template_folder {
+        if search_folder == template_base_folder {
             bail!("File not found within template");
         }
         search_folder = search_folder
@@ -427,17 +428,25 @@ fn expand_template(
 
     let all_hook_files = template_config.get_hook_files();
 
-    execute_pre_hooks(dir, &liquid_object, &mut template_config)?;
+    let mut liquid_object = Rc::new(RefCell::new(liquid_object));
+
+    execute_pre_hooks(dir, Rc::clone(&liquid_object), &mut template_config)?;
     ignore_me::remove_unneeded_files(dir, &template_cfg.ignore, args.verbose)?;
     let mut pbar = progressbar::new();
+
+    // SAFETY: We gave a clone of the Rc to `execute_pre_hooks` which by now has already been dropped. Therefore, there
+    // is no other pointer into this Rc which makes it safe to `get_mut`.
+    let liquid_object_ref = Rc::get_mut(&mut liquid_object).unwrap().get_mut();
+
     template::walk_dir(
         dir,
-        &liquid_object,
+        liquid_object_ref,
         &mut template_cfg,
         &all_hook_files,
         &mut pbar,
     )?;
-    execute_post_hooks(dir, &liquid_object, &template_config)?;
+
+    execute_post_hooks(dir, Rc::clone(&liquid_object), &template_config)?;
     remove_dir_files(all_hook_files, false);
 
     pbar.join().unwrap();
